mPME is similar to PME+ in the sense that it uses a scaling factor. However,
mPME uses different scaling factors for cash flows at different time intervals.
Thus, it attempts to improve the limitations of PME+ where a single coefficient
λ is used to scale all distributions.

See also:
- <https://en.wikipedia.org/wiki/Public_Market_Equivalent#Modified_PME>
- <https://blog.edda.co/advanced-fund-performance-methods-pme-direct-alpha/>
